
#define RECORDING_USD_CYCLE_SECONDS		5 //amount of seconds until it records data to uSD

#include <string.h>
#include "hardware.h"
#include "Axon_Mote_utils.h"	//all the extra code you need to get running
#include "pressure_BMP085.h"	//pressure sensor code

//comment out if you aren't using a microSD
//(it'll hang if you don't have one plugged in)
#define USE_uSD //make sure you used Project Designer to enable spiBus for the proper hardware.h file
#ifdef USE_uSD
	FATFILE f;
	FATFILE g;
#endif

//keep track of minutes
TICK_COUNT time_usd_start=0;
TICK_COUNT time_usd_threshold=1000000*RECORDING_USD_CYCLE_SECONDS;


uint16_t temperature2val=0;


void update_sensor_data(void);
void store_to_uSD(void);


// Initialise the hardware
void appInitHardware(void) {
	initHardware();
}
// Initialise the software
TICK_COUNT appInitSoftware(TICK_COUNT loopStart){

	delay_ms(1500);//let caps charge up

	//power on
	LED_on(&Green_LED);
	LED_on(&Red_LED);

	//get calibration values for pressure sensor
	BMP085_Calibration();
	LED_off(&Red_LED);

	//power reset safety code
	rprintf("\n\nAxon Mote Activated.");


	//turn off green, signals program is now running
	LED_off(&Green_LED);

	time_usd_start = clockGetus();

	return 0;
}
// This is the main loop
TICK_COUNT appControl(LOOP_COUNT loopCount, TICK_COUNT loopStart) {

	//store data to uSD
	if(clockHasElapsed(time_usd_start, time_usd_threshold))
		{
		//reset timer
		time_usd_start = clockGetus();

		//rprintf("\nwriting to uSD");

		update_sensor_data();
		rprintf("\n%d:%ld",temperature, pressure);

		//store to uSD
		
		LED_on(&Green_LED);
		store_to_uSD();//store sensor data
		LED_off(&Green_LED);
		}

	return 0;
}


//update all analog sensor data
void update_sensor_data(void)
	{

	BMP085_Convert();//get pressure and temp data
	}

void store_to_uSD(void)
	{
	#ifdef USE_uSD

		// -------- SDcard Code -------
		//if file doesn't exist, say so
		if(fileExists(&disk_sdCard,"/SANDY.TXT")==0)
			rprintf("\nFile doesn't already exist, creating /SANDY.TXT\n"); // => PC

		//open file, and create if doesn't exist
		int8_t fileOpen_value;
		fileOpen_value = fileOpen(&disk_sdCard,&f,"/SANDY.TXT",'a');

		//write to file
		if(fileOpen_value==0)
			{
			// Redirect output to the file
			Writer old = rprintfInit(fileGetWriter(&f));

			//write data
			//rprintf("\n%ld:%ld",sensorBMP085.pressure.pa, sensorBMP085.temperature.c);
			rprintf("\n%d:%ld",temperature, pressure);

			//close and save file
			fileClose(&f);

			// Restore rprintf to go to its original location
			rprintfInit(old);
			}
		else
			fileOpen_errors(fileOpen_value); //report error

		// -------- End SDcard Code -------
	#endif

	}

